@@ -13,9 +13,13 @@ In main urls you should have something like:
 import os
 from django.conf.urls.defaults import *
 from django.conf import settings
+from views import addons_view
 
 urlpatterns = patterns('')
 
+if settings.DEBUG:
+    urlpatterns += patterns('', url(r'^addons/$', addons_view))
+
 for addon in settings.ADDONS:
     filename = "%s/%s/urls.py" % (settings.ADDONS_ROOT, addon)
     fullname = "%s.%s.urls" % (settings.ADDONS_PREFIX, addon)
